#ifndef DISPLAY_AUTO_CHECK
#define DISPLAY_AUTO_CHECK

enum DisplayFont
{
    em_0,
    em_1,
    em_2,
    em_3,
    em_4,
    em_5,
    em_6,
    em_7,
    em_8,
    em_9,
    em_HENG,
    em_A,
    em_B,
    em_C,
    em_D,
    em_E,
    em_F,
    em_G,
    em_H,
    em_I,
    em_J,
    em_K,
    em_L,
    em_M,
    em_N,
    em_O,
    em_P,
    em_Q,
    em_R,
    em_S,
    em_T,
    em_U,
    em_V,
    em_W,
    em_X,
    em_Y,
    em_Z,
    em_DIAN,
    em_cuo,
    em_dui,
};
extern unsigned int Display_Menu_Type;

void GeneralInfoDisp(unsigned char  *p, unsigned short x, unsigned short y);
void Display_Title_Info(void);
void Display_Version_Info(void);
void Display_Line_CheckResult(void);
void Display_Res_CheckResult(void);
void Display_Voice_CheckResult(void);
void Display_TFT_CheckResult(void);
void Display_SegLCD_CheckResult(void);
void Display_Static_Current_CheckResult(void);
void Display_Total_Current_CheckResult(void);
void Display_BACk_CheckResult(void);
void Display_FUNC_CHECK(void);
void Display_Sch(void);
void Display_TFT_Clear(void);
void Display_Add(void);
unsigned int Get_Display_Type(void);
void Version_Info(unsigned int  ON_OFF);
void Display_OIL_R_W(unsigned int type, unsigned int ret);
void General_Number_Disp(unsigned char *p, unsigned short x, unsigned short y);
void Display_Sub(void);
#endif
